package cn.com.infosec.asn1.x9;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.math.ec.ECCurve;
import cn.com.infosec.math.ec.ECPoint;
import java.math.BigInteger;

public class X9ECParameters extends ASN1Encodable implements X9ObjectIdentifiers {
   private static final BigInteger ONE = BigInteger.valueOf(1L);
   private X9FieldID fieldID;
   private ECCurve curve;
   private ECPoint g;
   private BigInteger n;
   private BigInteger h;
   private byte[] seed;

   public X9ECParameters(ASN1Sequence seq) {
      BigInteger var2;
      if (seq.getObjectAt(0) instanceof DERInteger && ((DERInteger)seq.getObjectAt(0)).getValue().equals(var2 = ONE)) {
         X9Curve var3;
         X9Curve var10006 = var3 = new X9Curve;
         X9FieldID var4;
         var4 = new X9FieldID.<init>((ASN1Sequence)seq.getObjectAt(1));
         var10006.<init>(var4, (ASN1Sequence)seq.getObjectAt(2));
         ECCurve var5;
         this.curve = var5 = var10006.getCurve();
         this.g = (new X9ECPoint(var5, (ASN1OctetString)seq.getObjectAt(3))).getPoint();
         this.n = ((DERInteger)seq.getObjectAt(4)).getValue();
         this.seed = var3.getSeed();
         if (seq.size() == 6) {
            this.h = ((DERInteger)seq.getObjectAt(5)).getValue();
         } else {
            this.h = var2;
         }

      } else {
         throw new IllegalArgumentException("bad version in X9ECParameters");
      }
   }

   public X9ECParameters(ECCurve curve, ECPoint g, BigInteger n) {
      X9ECParameters var10000 = this;
      BigInteger var4 = ONE;
      var10000.<init>(curve, g, n, var4, (byte[])null);
   }

   public X9ECParameters(ECCurve curve, ECPoint g, BigInteger n, BigInteger h) {
      this(curve, g, n, h, (byte[])null);
   }

   public X9ECParameters(ECCurve curve, ECPoint g, BigInteger n, BigInteger h, byte[] seed) {
      this.curve = curve;
      this.g = g;
      this.n = n;
      this.h = h;
      this.seed = seed;
      if (curve instanceof ECCurve.Fp) {
         this.fieldID = new X9FieldID(((ECCurve.Fp)curve).getQ());
      } else if (curve instanceof ECCurve.F2m) {
         X9ECParameters var10000 = this;
         ECCurve.F2m var6 = (ECCurve.F2m)curve;
         X9FieldID curve1;
         X9FieldID var10001 = curve1 = new X9FieldID;
         ECCurve.F2m var10002 = var6;
         ECCurve.F2m var10003 = var6;
         ECCurve.F2m var10004 = var6;
         int var7 = var6.getM();
         int g1 = var10004.getK1();
         int n1 = var10003.getK2();
         int h1 = var10002.getK3();
         var10001.<init>(var7, g1, n1, h1);
         var10000.fieldID = curve1;
      }

   }

   public ECCurve getCurve() {
      return this.curve;
   }

   public ECPoint getG() {
      return this.g;
   }

   public BigInteger getN() {
      return this.n;
   }

   public BigInteger getH() {
      return this.h;
   }

   public byte[] getSeed() {
      return this.seed;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(new DERInteger(1));
      var10001.add(this.fieldID);
      ECCurve var2 = this.curve;
      var10001.add(new X9Curve(var2, this.seed));
      var10001.add(new X9ECPoint(this.g));
      var10001.add(new DERInteger(this.n));
      if (!this.h.equals(BigInteger.valueOf(1L))) {
         var1.add(new DERInteger(this.h));
      }

      return new DERSequence(var1);
   }
}
